.. _common:

==========================
Common utitlities
==========================

Current site, STATIC_URL context processors
===========================================

.. automodule:: fragapy.common.context_processors
    :members:
    
Middleware for limiting access, shortening HTML responses
=========================================================

.. automodule:: fragapy.common.middleware
    :members:
    
    
{% macro %} templatetag
=======================

.. automodule:: fragapy.common.templatetags.macros
